@@ -18,10 +18,10 @@ class JsonStorage(dict):
     """
     persistent python dict
     """
-    lock = threading.Lock()
 
     def __init__(self, path):
         super().__init__()
+        self.lock = threading.Lock()
         self.path = path
         if self.path:
             self.load_local(self.path)
